@@ -3,7 +3,9 @@
 set -ex
 
 # Remove -D_LIBCPP_DISABLE_AVAILABILITY once libcxx=12 is released
-CXXFLAGS="${CXXFLAGS} -D__STDC_FORMAT_MACROS -D_LIBCPP_DISABLE_AVAILABILITY" cmake \
+export CXXFLAGS="${CXXFLAGS} -D__STDC_FORMAT_MACROS -D_LIBCPP_DISABLE_AVAILABILITY"
+
+cmake ${CMAKE_ARGS} \
     -DCMAKE_BUILD_TYPE=Release \
     -DCMAKE_CXX_FLAGS_RELEASE="-Wall -Wextra -O3 -funroll-loops -DNDEBUG" \
     -DCMAKE_INSTALL_PREFIX=$PREFIX \
@@ -12,4 +14,5 @@ CXXFLAGS="${CXXFLAGS} -D__STDC_FORMAT_MACROS -D_LIBCPP_DISABLE_AVAILABILITY" cma
     -DWITH_XEUS=yes \
     $SRC_DIR
 
-cmake --build . --target install
+make -j${CPU_COUNT}
+make install
